@@ -13,7 +13,6 @@ from collections import OrderedDict
 from mnemonic import Mnemonic
 from hwilib.serializations import PSBT, CTransaction
 from .persistence import read_json_file, write_json_file
-from .util.descriptor import AddChecksum
 from .util.bcur import bcur_decode
 import threading
 from io import BytesIO
@@ -25,6 +24,10 @@ logger = logging.getLogger(__name__)
 defaultlock = threading.Lock()
 
 
+def is_testnet(chain):
+    return chain in ["test", "regtest", "signet"]
+
+
 def locked(customlock=defaultlock):
     """
     @locked(lock) decorator.
@@ -47,7 +50,9 @@ def to_ascii20(name: str) -> str:
     """
     Converts the name to max 20 ascii-only characters.
     """
-    return "".join([c for c in name if c.isascii()])[:20]
+    # ascii characters have codes from 0 to 127
+    # but 127 is "delete" and we don't want it
+    return "".join([c for c in name if ord(c) < 127])[:20]
 
 
 def alias(name):
@@ -162,58 +167,20 @@ def get_devices_with_keys_by_type(app, cosigners, wallet_type):
     for cosigner in cosigners:
         device = copy.deepcopy(cosigner)
         allowed_types = ["", wallet_type]
+        if wallet_type == "simple":
+            allowed_types += ["sh-wpkh", "wpkh"]
+        elif wallet_type == "multisig":
+            allowed_types += ["sh-wsh", "wsh"]
         device.keys = [
             key
             for key in device.keys
-            if key.xpub.startswith(prefix) and key.key_type in allowed_types
+            if key.xpub.startswith(prefix)
+            and (key.key_type in allowed_types or wallet_type == "*")
         ]
         devices.append(device)
     return devices
 
 
-def sort_descriptor(rpc, descriptor, index=None, change=False):
-    descriptor = descriptor.replace("sortedmulti", "multi")
-    if index is not None:
-        descriptor = descriptor.replace("*", f"{index}")
-    # remove checksum
-    descriptor = descriptor.split("#")[0]
-    # get address (should be already imported to the wallet)
-    address = rpc.deriveaddresses(AddChecksum(descriptor), change=change)[0]
-
-    # get pubkeys involved
-    address_info = rpc.getaddressinfo(address)
-    if "pubkeys" in address_info:
-        pubkeys = address_info["pubkeys"]
-    elif "embedded" in address_info and "pubkeys" in address_info["embedded"]:
-        pubkeys = address_info["embedded"]["pubkeys"]
-    else:
-        raise Exception(
-            "Could not find 'pubkeys' in address info:\n%s"
-            % json.dumps(address_info, indent=2)
-        )
-
-    # get xpubs from the descriptor
-    arr = descriptor.split("(multi(")[1].split(")")[0].split(",")
-
-    # getting [wsh] or [sh, wsh]
-    prefix = descriptor.split("(multi(")[0].split("(")
-    sigs_required = arr[0]
-    keys = arr[1:]
-
-    # sort them according to sortedmulti
-    z = sorted(zip(pubkeys, keys), key=lambda x: x[0])
-    keys = [zz[1] for zz in z]
-    inner = f"{sigs_required}," + ",".join(keys)
-    desc = f"multi({inner})"
-
-    # Write from the inside out
-    prefix.reverse()
-    for p in prefix:
-        desc = f"{p}({desc})"
-
-    return AddChecksum(desc)
-
-
 def clean_psbt(b64psbt):
     psbt = PSBT()
     psbt.deserialize(b64psbt)
@@ -258,22 +225,3 @@ def generate_mnemonic(strength=256):
     mnemo = Mnemonic("english")
     words = mnemo.generate(strength=strength)
     return words
-
-
-# Transaction processing helpers
-def parse_utxo(wallet, utxo):
-    for tx in utxo:
-        tx_data = wallet.rpc.gettransaction(tx["txid"])
-        tx["time"] = tx_data["time"]
-        if len(tx_data["details"]) > 1:
-            for details in tx_data["details"]:
-                if details["category"] != "send":
-                    tx["category"] = details["category"]
-                    break
-        else:
-            tx["category"] = tx_data["details"][0]["category"]
-        if "confirmations" in tx_data:
-            tx["confirmations"] = tx_data["confirmations"]
-        else:
-            tx["confirmations"] = 0
-    return utxo
