@@ -2,11 +2,13 @@ import copy
 import json
 import logging
 import os
+import traceback
 import random
 import time
 import zipfile
 from io import BytesIO
-from .helpers import deep_update, clean_psbt
+from .helpers import deep_update, clean_psbt, is_testnet
+from .util.checker import Checker
 from .rpc import autodetect_rpc_confs, get_default_datadir, RpcError
 from urllib3.exceptions import NewConnectionError
 from requests.exceptions import ConnectionError
@@ -16,6 +18,7 @@ from .wallet_manager import WalletManager
 from .user_manager import UserManager
 from .persistence import write_json_file, read_json_file
 from .user import User
+from .util.price_providers import update_price
 import threading
 
 logger = logging.getLogger(__name__)
@@ -49,7 +52,6 @@ def get_rpc(conf, old_rpc=None):
         rpc = BitcoinRPC(**conf)
     # check if we have something to compare with
     if old_rpc is None:
-        logger.info("rpc config have changed.")
         return rpc
     # check if we have something detected
     if rpc is None:
@@ -64,47 +66,6 @@ def get_rpc(conf, old_rpc=None):
         return rpc
 
 
-class Checker:
-    """
-    Checker class that calls the periodic callback.
-    If you want to force-check within the next second
-    set checker.last_check to 0.
-    """
-
-    def __init__(self, callback, period=600):
-        self.callback = callback
-        self.last_check = 0
-        self.period = period
-        self.running = False
-
-    def start(self):
-        if not self.running:
-            self.running = True
-            self.thread = threading.Thread(target=self.loop)
-            self.thread.daemon = True
-            self.thread.start()
-
-    def stop(self):
-        logger.info("Checker stopped.")
-        self.running = False
-
-    def loop(self):
-        while self.running:
-            # check if it's time to update
-            if time.time() - self.last_check >= self.period:
-                try:
-                    t0 = time.time()
-                    self.callback()
-                    dt = time.time() - t0
-                    logger.info("Checker checked in %.3f seconds" % dt)
-                except Exception as e:
-                    logger.error(e)
-                finally:
-                    self.last_check = time.time()
-            # wait 1 second
-            time.sleep(1)
-
-
 class Specter:
     """ A central Object mostly holding app-settings """
 
@@ -150,14 +111,24 @@ class Specter:
             # empty by default for backward-compatibility
             "uid": "",
             "unit": "btc",
+            "price_check": False,
+            "alt_rate": 1,
+            "alt_symbol": "BTC",
+            "price_provider": "",
             "validate_merkle_proofs": False,
         }
 
         # health check: loads config, tests rpc
         # also loads and checks wallets for all users
-        self.check(check_all=True)
+        try:
+            self.check(check_all=True)
+        except Exception as e:
+            logger.error(e)
         self.checker = Checker(lambda: self.check(check_all=True))
         self.checker.start()
+        self.price_checker = Checker(lambda: update_price(self, self.user))
+        if self.price_check and self.price_provider:
+            self.price_checker.start()
 
     def check(self, user=None, check_all=False):
         """
@@ -177,9 +148,9 @@ class Specter:
             rpc = get_rpc(self.config["rpc"], self.rpc)
 
         # if rpc is not available
-        # do checks more often, once in 3 seconds
+        # do checks more often, once in 20 seconds
         if rpc is None:
-            period = 3
+            period = 20
         else:
             period = 600
         if hasattr(self, "checker") and self.checker.period != period:
@@ -270,7 +241,7 @@ class Specter:
                 wallets_folder,
                 self.rpc,
                 self.chain,
-                self.device_manager,
+                user.device_manager,
                 path=wallets_rpcpath,
             )
             user.wallet_manager = wallet_manager
@@ -477,6 +448,39 @@ class Specter:
         else:
             user.set_unit(self, unit)
 
+    def update_price_check_setting(self, price_check_bool, user):
+        if user.is_admin:
+            self.config["price_check"] = price_check_bool
+            self._save()
+        else:
+            user.set_price_check(self, price_check_bool)
+        if price_check_bool and (self.price_provider and self.user == user):
+            self.price_checker.start()
+        else:
+            self.price_checker.stop()
+
+    def update_price_provider(self, price_provider, user):
+        if user.is_admin:
+            self.config["price_provider"] = price_provider
+            self._save()
+        else:
+            user.set_price_provider(self, price_provider)
+
+    def update_alt_rate(self, alt_rate, user):
+        alt_rate = round(float(alt_rate), 2)
+        if user.is_admin:
+            self.config["alt_rate"] = alt_rate
+            self._save()
+        else:
+            user.set_alt_rate(self, alt_rate)
+
+    def update_alt_symbol(self, alt_symbol, user):
+        if user.is_admin:
+            self.config["alt_symbol"] = alt_symbol
+            self._save()
+        else:
+            user.set_alt_symbol(self, alt_symbol)
+
     def update_merkleproof_settings(self, validate_bool):
         if validate_bool is True and self.info.get("pruned") is True:
             validate_bool = False
@@ -562,6 +566,10 @@ class Specter:
     def chain(self):
         return self._info["chain"]
 
+    @property
+    def is_testnet(self):
+        return is_testnet(self.chain)
+
     @property
     def user_config(self):
         return self.config if self.user.is_admin else self.user.config
@@ -578,6 +586,22 @@ class Specter:
     def unit(self):
         return self.user_config.get("unit", "btc")
 
+    @property
+    def price_check(self):
+        return self.user_config.get("price_check", False)
+
+    @property
+    def price_provider(self):
+        return self.user_config.get("price_provider", False)
+
+    @property
+    def alt_rate(self):
+        return self.user_config.get("alt_rate", 1)
+
+    @property
+    def alt_symbol(self):
+        return self.user_config.get("alt_symbol", "BTC")
+
     @property
     def admin(self):
         for u in self.users:
@@ -605,7 +629,8 @@ class Specter:
                     data.date_time = time.localtime(time.time())[:6]
                     data.compress_type = zipfile.ZIP_DEFLATED
                     zf.writestr(
-                        "wallets/{}.json".format(wallet.alias), json.dumps(wallet.json)
+                        "wallets/{}.json".format(wallet.alias),
+                        json.dumps(wallet.to_json(for_export=True)),
                     )
             if self.device_manager:
                 for device in self.device_manager.devices.values():
